@@ -762,12 +762,14 @@ get_url (GrlNetWc *self,
 
   if ((now.tv_sec - priv->last_request.tv_sec) > priv->throttling
           || is_mocked()) {
+    priv->last_request = now;
     id = g_idle_add_full (G_PRIORITY_HIGH_IDLE,
                           get_url_cb, c, request_clos_destroy);
   } else {
-    GRL_DEBUG ("delaying web request");
-
     priv->last_request.tv_sec += priv->throttling;
+
+    GRL_DEBUG ("delaying web request by %lu seconds",
+               priv->last_request.tv_sec - now.tv_sec);
     id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
                                      priv->last_request.tv_sec - now.tv_sec,
                                      get_url_cb, c, request_clos_destroy);
@@ -945,7 +947,8 @@ grl_net_wc_request_with_headers_hash_async (GrlNetWc *self,
  * grl_net_wc_request_finish:
  * @self: a #GrlNetWc instance
  * @result: The result of the request
- * @content: (out) (allow-none) (transfer none): The contents of the resource
+ * @content: (out) (array length=length) (element-type guint8) (allow-none)
+ * (transfer full): The contents of the resource
  * @length: (out) (allow-none): The length of the contents or %NULL if it is not
  * needed
  * @error: return location for a #GError, or %NULL
